import { History, Location } from 'history';
import * as React from 'react';
import { match, RouteComponentProps, RouteProps } from 'react-router';
declare type CacheDom = HTMLElement | null;
declare type LivePath = string | string[] | undefined;
interface IMatchOptions {
    path?: string | string[];
    exact?: boolean;
    strict?: boolean;
    sensitive?: boolean;
}
declare enum LiveState {
    NORMAL_RENDER_MATCHED = "normal matched render",
    NORMAL_RENDER_UNMATCHED = "normal unmatched render (unmount)",
    NORMAL_RENDER_ON_INIT = "normal render (matched or unmatched)",
    HIDE_RENDER = "hide route when livePath matched"
}
declare type OnRoutingHook = (location: Location, match: match | null, history: History, livePath: LivePath, alwaysLive: boolean | undefined) => any;
interface IProps extends RouteProps {
    name?: string;
    livePath?: string | string[];
    alwaysLive?: boolean;
    onHide?: OnRoutingHook;
    onReappear?: OnRoutingHook;
    forceUnmount?: OnRoutingHook;
    computedMatch?: IMatchOptions;
}
/**
 * The public API for matching a single path and rendering.
 */
declare type PropsType = RouteComponentProps<any> & IProps;
declare class LiveRoute extends React.Component<PropsType, any> {
    routeDom: CacheDom;
    scrollPosBackup: {
        left: number;
        top: number;
    } | null;
    previousDisplayStyle: string | null;
    liveState: LiveState;
    componentDidMount(): void;
    componentDidUpdate(prevProps: any, prevState: any): void;
    componentWillUnmount(): void;
    getRouteDom(): void;
    hideRoute(): void;
    showRoute(): void;
    doesRouteEnableLive(): string | boolean | string[] | undefined;
    saveScrollPosition(): void;
    restoreScrollPosition(): void;
    clearDomData(): void;
    clearScroll(): void;
    isLivePathMatch(livePath: LivePath, alwaysLive: boolean | undefined, pathname: string, options: IMatchOptions): match<{}> | null;
    render(): {} | null | undefined;
}
export default LiveRoute;
